=======
Credits
=======

Development Lead
----------------

* zfit <zfit@physik.uzh.ch>

Contributors
------------

| Jonas Eschle <jonas.eschle@cern.ch>
| Michele Atzeni <michele.atzeni@cern.ch>
| Andrea Mauri <a.mauri@cern.ch>
| Anton Poluektov <anton.poluektov@cern.ch>
| Albert Puig <albert.puig@cern.ch>
| Nicola Serra <nicola.serra@cern.ch>
| Rafael Silva Coutinho <rsilvaco@cern.ch>
| Zhenzi Wang <zhenzi@physik.uzh.ch>

